@@ -329,7 +329,7 @@ MVNMissImpute <- function(
   
   # Restore initial order. 
   init_order <- split_data$init_order
-  out <- out[order(init_order), ]
+  out <- out[order(init_order), , drop = FALSE]
   
   # Output
   rownames(out) <- split_data$orig_row_names
